@@ -23,17 +23,18 @@ import sys
  
 from Iuno import DEVELOPMENT, STAGE, PRODUCTION
 
-# Generally, this project should run at PRODUCTION mode, 
-# don't modify the SERVER_MODE.
-# see https://code.nuwainfo.com/trac/mercurius/ticket/2843
-
 SERVER_MODE = PRODUCTION
+# Generally, this project should run at PRODUCTION mode, 
+import Iuno
+
+# SERVER_MODE = Iuno.detectServerMode(locals())
+# DEBUG = Iuno.detectDebug(locals())
 #============================================================================
 
 #============================================================================
 # Project settings.
 
-APP_NAME = 'mail'
+APP_NAME = 'mailworker'
 APP_VERSION = "0.3.0." + "$Revision: 9315 $"[11:-2]
  
 INSTALLED_APPS = (
@@ -52,6 +53,7 @@ ROOT_URLCONF = 'mail.urls'
 # Administration. 
 ADMINS = (
     ('Bear', 'bear@tracedig.com'),
+    ('David', 'david.lee@nuwainfo.com')
 )
  
 # Make this unique, and don't share it with anybody.
@@ -75,7 +77,6 @@ else:
     # http://docs.pythonboto.org/en/latest/boto_config_tut.html
     botoCfg = os.path.abspath(
         os.path.join(os.path.dirname(__file__), '..', '.boto'))
-    print botoCfg
     if not os.path.exists(botoCfg):
         raise RuntimeError('You must setup .boto file to store AWS credentials '
                            'that has SES send authorization.')
@@ -109,8 +110,7 @@ IUNO_CLOUD_SERVICES = ('queue', 'mail', 'browser')
  
 IUNO_CLOUD_LOGGING_FILE = os.path.join(os.path.dirname(__file__), 'mail.log')
 #============================================================================
-ALLOWED_DOMAINS = []
-import Iuno
+ALLOWED_DOMAINS = ['extension.mail', ]
 Iuno.attachSettings(locals())
 
 BASE_DIR = os.path.dirname(os.path.dirname(__file__))
