@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9991 2017-05-28 11:00:12Z David $
+# $Id: __init__.py 9994 2017-05-28 14:47:33Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-05-28 19:00:12 +0800 (Sun, 28 May 2017) $
-# $Revision: 9991 $
+# $Date: 2017-05-28 22:47:33 +0800 (Sun, 28 May 2017) $
+# $Revision: 9994 $
 
 import os
 import sys
@@ -303,7 +303,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         ALLOWED_HOSTS = ['127.0.0.1', 'localhost']
     
     defaultAllowedDomains = {
-        ALLOWED_DOMAINS: ['127.0.0.1', 'localhost']
+        'ALLOWED_DOMAINS': ['127.0.0.1', 'localhost']
     }
 
     if settingsDict.get('ALLOWED_DOMAINS', None):
